@@ -3,10 +3,10 @@
 # A small script to help run example apps
 #
 
-prefix=/home/jeff/install
+prefix=/usr/local
 exec_prefix=${prefix}
 libdir=${exec_prefix}/lib
-classpath=${prefix}/share/java/gconf2.9-2.9.92.jar
+classpath=${prefix}/share/java/gconf2.10-2.10.1.jar
 
 GCONFJAVA_LIB=$libdir
 GCONFJAVA_JAR=$classpath
