@@ -10,7 +10,7 @@
 #include <jni.h>
 #include <gconf/gconf.h>
 #include <gconf/gconf-client.h>
-#include "jg_jnu.h"
+#include <jg_jnu.h>
 
 #ifndef _Included_org_gnu_gconf_ConfClient
 #define _Included_org_gnu_gconf_ConfClient
